@@ -4,9 +4,8 @@
  * The license is same as the one on the root.
 */
 
-extern crate nalgebra_glm as glm;
-
 pub(crate) mod definition;
+pub mod gui;
 pub mod header;
 pub mod objects;
 pub mod render;
