@@ -13,14 +13,14 @@ impl Camera {
     /// Creates a new camera. this should've been automatically done at the time of creating an engine
     pub fn new(renderer: &Renderer) -> Result<Self> {
         let mut camera = Self {
-            eye: glm::vec3(0.0, 0.0, 1.0),
-            target: glm::vec3(0.0, 0.0, 0.0).into(),
-            up: glm::vec3(0.0, 1.0, 0.0),
+            position: nalgebra_glm::vec3(0.0, 0.0, 1.0),
+            target: nalgebra_glm::vec3(0.0, 0.0, -1.0).into(),
+            up: nalgebra_glm::vec3(0.0, 1.0, 0.0),
             aspect: renderer.config.width as f32 / renderer.config.height as f32,
-            fov: 45.0,
+            fov: 70f32 * (std::f32::consts::PI / 180f32),
             near: 0.1,
             far: 100.0,
-            view_data: DEFAULT_MATRIX_4,
+            view_data: DEFAULT_MATRIX_4.to_im(),
             changed: true,
         };
         camera.build_view_projection_matrix()?;
@@ -30,8 +30,8 @@ impl Camera {
 
     /// Updates the view uniform matrix that decides how camera works
     pub fn build_view_projection_matrix(&mut self) -> Result<()> {
-        let view = glm::ext::look_at_rh(self.eye, self.target, self.up);
-        let proj = glm::ext::perspective::<f32>(self.fov, self.aspect, self.near, self.far);
+        let view = nalgebra_glm::look_at_rh(&self.position, &self.target, &self.up);
+        let proj = nalgebra_glm::perspective(self.fov, self.aspect, self.near, self.far);
         self.view_data = proj * view;
         self.changed = true;
 
@@ -40,28 +40,28 @@ impl Camera {
 
     /// Returns a matrix uniform buffer from camera data that can be sent to GPU
     pub fn camera_uniform_buffer(&self) -> Result<Matrix> {
-        Ok(Matrix::from_glm(self.view_data))
+        Ok(Matrix::from_im(self.view_data))
     }
 
-    /// Sets the eye of camera
-    pub fn set_eye(&mut self, new_eye: [f32; 3]) -> Result<()> {
-        self.eye = glm::vec3(new_eye[0], new_eye[1], new_eye[2]);
+    /// Sets the position of camera
+    pub fn set_position(&mut self, x: f32, y: f32, z: f32) -> Result<()> {
+        self.position = nalgebra_glm::vec3(x, y, z);
         self.build_view_projection_matrix()?;
 
         Ok(())
     }
 
     /// Sets the target of camera
-    pub fn set_target(&mut self, new_target: [f32; 3]) -> Result<()> {
-        self.target = glm::vec3(new_target[0], new_target[1], new_target[2]);
+    pub fn set_target(&mut self, x: f32, y: f32, z: f32) -> Result<()> {
+        self.target = nalgebra_glm::vec3(x, y, z);
         self.build_view_projection_matrix()?;
 
         Ok(())
     }
 
     /// Sets the up of camera
-    pub fn set_up(&mut self, new_up: [f32; 3]) -> Result<()> {
-        self.up = glm::vec3(new_up[0], new_up[1], new_up[2]);
+    pub fn set_up(&mut self, x: f32, y: f32, z: f32) -> Result<()> {
+        self.up = nalgebra_glm::vec3(x, y, z);
         self.build_view_projection_matrix()?;
 
         Ok(())
